package com.zd.chemical.service;

import java.util.List;
import com.zd.chemical.domain.HxpChemicalClassify;

/**
 * 化学品分类Service接口
 *
 * @author zd
 * @date 2022-06-21
 */
public interface IHxpChemicalClassifyService
{
    /**
     * 查询化学品分类
     *
     * @param id 化学品分类主键
     * @return 化学品分类
     */
    public HxpChemicalClassify selectHxpChemicalClassifyById(Long id);

    /**
     * 查询化学品分类列表
     *
     * @param hxpChemicalClassify 化学品分类
     * @return 化学品分类集合
     */
    public List<HxpChemicalClassify> selectHxpChemicalClassifyList(HxpChemicalClassify hxpChemicalClassify);

    /**
     * 新增化学品分类
     *
     * @param hxpChemicalClassify 化学品分类
     * @return 结果
     */
    public int insertHxpChemicalClassify(HxpChemicalClassify hxpChemicalClassify);

    /**
     * 修改化学品分类
     *
     * @param hxpChemicalClassify 化学品分类
     * @return 结果
     */
    public int updateHxpChemicalClassify(HxpChemicalClassify hxpChemicalClassify);

    /**
     * 批量删除化学品分类
     *
     * @param ids 需要删除的化学品分类主键集合
     * @return 结果
     */
    public int deleteHxpChemicalClassifyByIds(Long[] ids);

    /**
     * 删除化学品分类信息
     *
     * @param id 化学品分类主键
     * @return 结果
     */
    public int deleteHxpChemicalClassifyById(Long id);
}
