package com.zd.chemical.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.zd.common.core.web.domain.ResultData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.chemical.domain.HxpChemicalClassify;
import com.zd.chemical.service.IHxpChemicalClassifyService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.zd.common.swagger.config.Knife4jConfiguration;
import com.zd.common.core.web.page.TableDataInfo;

/**
 * 化学品分类Controller
 *
 * @author zd
 * @date 2022-06-21
 */
@RestController
@Api(tags = "【化学品分类】")
//作者手动加入 ，在接口上加作者@ApiOperationSupport(author = "XXX")
@ApiSupport(author = Knife4jConfiguration.Author.CYL)
@RequestMapping("/classify")
public class HxpChemicalClassifyController extends BaseController
{
    @Autowired
    private IHxpChemicalClassifyService hxpChemicalClassifyService;

    /**
     * 查询化学品分类列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "查询化学品分类列表")
    public TableDataInfo<HxpChemicalClassify> list(HxpChemicalClassify hxpChemicalClassify)
    {
        startPage();
        List<HxpChemicalClassify> list = hxpChemicalClassifyService.selectHxpChemicalClassifyList(hxpChemicalClassify);
        return getDataTable(list);
    }

    /**
     * 导出化学品分类列表
     */
    @ApiOperation(value = "导出化学品分类列表")
    @Log(title = "化学品分类", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, HxpChemicalClassify hxpChemicalClassify) throws IOException
    {
        List<HxpChemicalClassify> list = hxpChemicalClassifyService.selectHxpChemicalClassifyList(hxpChemicalClassify);
        ExcelUtil<HxpChemicalClassify> util = new ExcelUtil<HxpChemicalClassify>(HxpChemicalClassify.class);
        util.exportExcel(response, list, "化学品分类数据");
    }

    /**
     * 获取化学品分类详细信息
     */
    @ApiOperation(value = "获取化学品分类详细信息")
    @GetMapping(value = "/{id}")
    public ResultData<HxpChemicalClassify> getInfo(@PathVariable("id") Long id)
    {
        return ResultData.success(hxpChemicalClassifyService.selectHxpChemicalClassifyById(id));
    }

    /**
     * 新增化学品分类
     */
    @ApiOperation(value = "新增化学品分类")
    @Log(title = "化学品分类", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody HxpChemicalClassify hxpChemicalClassify)
    {
        return ResultData.result(hxpChemicalClassifyService.insertHxpChemicalClassify(hxpChemicalClassify));
    }

    /**
     * 修改化学品分类
     */
    @ApiOperation(value = "修改化学品分类")
    @Log(title = "化学品分类", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody HxpChemicalClassify hxpChemicalClassify)
    {
        return  ResultData.result(hxpChemicalClassifyService.updateHxpChemicalClassify(hxpChemicalClassify));
    }

    /**
     * 删除化学品分类
     */
    @ApiOperation(value = "删除化学品分类")
    @Log(title = "化学品分类", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids)
    {
        return ResultData.result(hxpChemicalClassifyService.deleteHxpChemicalClassifyByIds(ids));
    }
}
